CellML Generics and Reflection Service for Python
=================================================

cgrspy is a Python interface to the CellML API, and allows you to work
with mathematical models in CellML formats from in Python.

The binding makes use of the CellML Generics and Reflection Service
(CGRS) to provide dynamically-typed Python bindings.

To use this binding, you must first obtain a build of the CellML API
that includes the CellML Generics and Reflection Service; CellML API
version 1.10 and earlier do not include this support.
